@@ -15,6 +15,7 @@ public:
   ~IndexList();
   IndexList* Copy();
   IndexList* CopyLen();
+  size_t* CopyList();
 
   size_t Length();
   void Fill();
@@ -23,8 +24,10 @@ public:
   void Shuffle();
 
   void Set(const size_t);
+  void Add(const size_t);
   size_t Get(const size_t);
   size_t GetK(const size_t);
+  size_t GetLast();
   bool Exists(const size_t);
   size_t Draw();
   void Erase(const size_t);
